{% load i18n %}
<h3>{{ title }}</h3>
<div class="anylogicfilter">
    <form method="GET" action="">
        {% for choice in choices %}
            <input type="hidden" name="{{ choice.key }}" value="{{ choice.value }}" />
        {% endfor %}
        {{ spec.form.as_p }}
        <p><input type="submit" value="Submit"></p>
    </form>
</div>
